"""Tests for individual booking methods.

Note that these should be already covered by the tests in booking_full_test, but
we may want to add more tests here, just calling each method directly and
covering all the possible branches.
"""

__copyright__ = "Copyright (C) 2017, 2019, 2024  Martin Blais"
__license__ = "GNU GPLv2"

import unittest

from beancount.parser import booking_method as bm  # noqa: F401

if __name__ == "__main__":
    unittest.main()
